@@ -2,7 +2,7 @@ require 'date'
 require 'fileutils'
 require 'spec_helper'
 
-describe FileUtils do
+RSpec.describe FileUtils do
   before :each do
     MemFs::File.umask(0020)
     MemFs.activate!
@@ -25,12 +25,12 @@ describe FileUtils do
     end
 
     it "raises an error when the given path doesn't exist" do
-      expect { described_class.cd('/nowhere') }.to raise_specific_error(Errno::ENOENT)
+      expect { described_class.cd('/nowhere') }.to raise_error(Errno::ENOENT)
     end
 
     it 'raises an error when the given path is not a directory' do
       described_class.touch('/test-file')
-      expect { described_class.cd('/test-file') }.to raise_specific_error(Errno::ENOTDIR)
+      expect { described_class.cd('/test-file') }.to raise_error(Errno::ENOTDIR)
     end
 
     context 'when called with a block' do
@@ -57,7 +57,7 @@ describe FileUtils do
       end
 
       it "raises an error if the last target of the link chain doesn't exist" do
-        expect { described_class.cd('/nowhere-link') }.to raise_specific_error(Errno::ENOENT)
+        expect { described_class.cd('/nowhere-link') }.to raise_error(Errno::ENOENT)
       end
     end
   end
@@ -82,7 +82,7 @@ describe FileUtils do
     end
 
     it 'raises an error if an entry does not exist' do
-      expect { described_class.chmod(0777, '/test-file') }.to raise_specific_error(Errno::ENOENT)
+      expect { described_class.chmod(0777, '/test-file') }.to raise_error(Errno::ENOENT)
     end
 
     context 'when the named file is a symlink' do
@@ -296,9 +296,12 @@ describe FileUtils do
 
     context 'when +src+ does not exist' do
       it 'raises an exception' do
+        expected_exception =
+          RUBY_VERSION >= '2.4.0' ? Errno::ENOENT : RuntimeError
+
         expect {
           described_class.copy_entry('/test-file', '/test-copy')
-        }.to raise_specific_error(RuntimeError)
+        }.to raise_error(expected_exception)
       end
     end
 
@@ -382,7 +385,7 @@ describe FileUtils do
       it 'raises an error' do
         expect {
           described_class.cp('/test-file', '/test-file')
-        }.to raise_specific_error(ArgumentError)
+        }.to raise_error(ArgumentError)
       end
     end
 
@@ -400,7 +403,7 @@ describe FileUtils do
           described_class.touch(['/dest', '/test-file2'])
           expect {
             described_class.cp(['/test-file', '/test-file2'], '/dest')
-          }.to raise_specific_error(Errno::ENOTDIR)
+          }.to raise_error(Errno::ENOTDIR)
         end
       end
     end
@@ -474,7 +477,7 @@ describe FileUtils do
       it 'raises an exception' do
         expect {
           described_class.install('/test-file', '/test-file')
-        }.to raise_exception(ArgumentError)
+        }.to raise_error ArgumentError
       end
     end
 
@@ -527,7 +530,7 @@ describe FileUtils do
           described_class.touch('/test-file2')
           expect {
             described_class.ln('/test-file', '/test-file2')
-          }.to raise_specific_error(SystemCallError)
+          }.to raise_error(SystemCallError)
         end
 
         context 'and +:force+ is set' do
@@ -552,7 +555,7 @@ describe FileUtils do
           described_class.touch(['/test-file2', '/not-a-dir'])
           expect {
             described_class.ln(['/test-file', '/test-file2'], '/not-a-dir')
-          }.to raise_specific_error(Errno::ENOTDIR)
+          }.to raise_error(Errno::ENOTDIR)
         end
       end
     end
@@ -587,7 +590,7 @@ describe FileUtils do
         it 'raises an exeption' do
           expect {
             described_class.ln_s('/test-file', '/not-a-dir')
-          }.to raise_specific_error(Errno::EEXIST)
+          }.to raise_error(Errno::EEXIST)
         end
 
         context 'and +:force+ is set' do
@@ -618,7 +621,7 @@ describe FileUtils do
         it 'raises an error' do
           expect {
             described_class.ln_s(['/test-file', '/test-file2'], '/not-a-dir')
-          }.to raise_specific_error(Errno::ENOTDIR)
+          }.to raise_error(Errno::ENOTDIR)
         end
       end
     end
@@ -667,8 +670,6 @@ describe FileUtils do
         end
       end
     end
-
-
   end
 
   describe '.mkdir_p' do
@@ -867,7 +868,7 @@ describe FileUtils do
 
     it 'cannot remove a directory' do
       described_class.mkdir('/test-dir')
-      expect { described_class.rm('/test-dir') }.to raise_specific_error(Errno::EPERM)
+      expect { described_class.rm('/test-dir') }.to raise_error(Errno::EPERM)
     end
 
     context 'when +:force+ is set' do
@@ -882,7 +883,9 @@ describe FileUtils do
 
   describe '.rm_f' do
     it 'calls rm with +:force+ set to true' do
-      expect(described_class).to receive(:rm).with('test', force: true)
+      expect(described_class)
+        .to receive(:rm).with('test', a_hash_including(force: true))
+
       described_class.rm_f('test')
     end
   end
@@ -917,7 +920,9 @@ describe FileUtils do
 
   describe '.rm_rf' do
     it 'calls rm with +:force+ set to true' do
-      expect(described_class).to receive(:rm_r).with('test', force: true)
+      expect(described_class)
+        .to receive(:rm_r).with('test', a_hash_including(force: true))
+
       described_class.rm_rf('test')
     end
   end
