@@ -1,7 +1,7 @@
 require 'spec_helper'
 
 module MemFs
-  describe File::Stat do
+  ::RSpec.describe File::Stat do
     let(:file_stat) { described_class.new('/test-file') }
     let(:dereferenced_file_stat) { described_class.new('/test-file', true) }
 
@@ -131,7 +131,7 @@ module MemFs
 
     describe '#dev' do
       it 'returns an integer representing the device on which stat resides' do
-        expect(file_stat.dev).to be_a(Fixnum)
+        expect(file_stat.dev).to be_a(Integer)
       end
     end
 
@@ -449,7 +449,7 @@ module MemFs
 
     describe '#ino' do
       it 'returns the inode number for stat.' do
-        expect(file_stat.ino).to be_a(Fixnum)
+        expect(file_stat.ino).to be_a(Integer)
       end
     end
 
@@ -606,6 +606,7 @@ module MemFs
 
       context 'when the file does not have the setgid bit set' do
         it 'returns false' do
+          _fs.chmod(0644, '/test-file')
           expect(file_stat.setgid?).to be false
         end
       end
@@ -621,6 +622,7 @@ module MemFs
 
       context 'when the file does not have the setuid bit set' do
         it 'returns false' do
+          _fs.chmod(0644, '/test-file')
           expect(file_stat.setuid?).to be false
         end
       end
@@ -643,6 +645,7 @@ module MemFs
       end
 
       it "returns false if the named file hasn't' the sticky bit set" do
+        _fs.chmod(0666, '/test-file')
         expect(file_stat.sticky?).to be false
       end
     end
