@@ -1,8 +1,10 @@
+# encoding: UTF-8
+
 require 'spec_helper'
 require 'pathname'
 
 module MemFs
-  describe File do
+  ::RSpec.describe File do
     subject { described_class.new('/test-file') }
     let(:write_subject) { described_class.new('/test-file', 'w') }
 
@@ -15,7 +17,6 @@ module MemFs
       described_class.symlink '/no-file', '/no-link'
     end
 
-
     it 'implements Enumerable' do
       expect(described_class.ancestors).to include Enumerable
     end
@@ -205,7 +206,7 @@ module MemFs
 
       it 'ignores -1 user id' do
         expect {
-          described_class.chown -1, 42, '/test-file'
+          described_class.chown(-1, 42, '/test-file')
         }.to_not change { described_class.stat('/test-file').uid }
       end
 
@@ -555,21 +556,21 @@ module MemFs
 
     describe '.ftype' do
       context 'when the named entry is a regular file' do
-        it "returns 'file'" do
+        it 'returns "file"' do
           ftype = described_class.ftype('/test-file')
           expect(ftype).to eq 'file'
         end
       end
 
       context 'when the named entry is a directory' do
-        it "returns 'directory'" do
+        it 'returns "directory"' do
           ftype = described_class.ftype('/test-dir')
           expect(ftype).to eq 'directory'
         end
       end
 
       context 'when the named entry is a block device' do
-        it "returns 'blockSpecial'" do
+        it 'returns "blockSpecial"' do
           _fs.touch '/block-file'
           file = _fs.find('/block-file')
           file.block_device = true
@@ -580,7 +581,7 @@ module MemFs
       end
 
       context 'when the named entry is a character device' do
-        it "returns 'characterSpecial'" do
+        it 'returns "characterSpecial"' do
           _fs.touch '/character-file'
           file = _fs.find('/character-file')
           file.character_device = true
@@ -591,7 +592,7 @@ module MemFs
       end
 
       context 'when the named entry is a symlink' do
-        it "returns 'link'" do
+        it 'returns "link"' do
           ftype = described_class.ftype('/test-link')
           expect(ftype).to eq 'link'
         end
@@ -600,7 +601,7 @@ module MemFs
       # fifo and socket not handled for now
 
       context 'when the named entry has no specific type' do
-        it "returns 'unknown'" do
+        it 'returns "unknown"' do
           root = _fs.find '/'
           root.add_entry Fake::Entry.new('test-entry')
 
@@ -727,7 +728,7 @@ module MemFs
           expect(mode).to be 0100777
         end
 
-        it "does not change permission bits on the link's target" do
+        it 'does not change permission bits on the link’s target' do
           old_mode = described_class.stat('/test-file').mode
           described_class.lchmod 0777, '/test-link'
 
@@ -791,18 +792,45 @@ module MemFs
           is_symlink = described_class.lstat('/test-link').symlink?
           expect(is_symlink).to be true
         end
-
-        context 'and its target does not exist' do
-          it 'ignores errors' do
-            expect {
-              described_class.lstat('/no-link')
-            }.not_to raise_error
-          end
-        end
       end
     end
 
     describe '.new' do
+      it 'resets the file position to the beginning' do
+        described_class.open('/test-file', 'w') { |f| f.write 'hello' }
+
+        contents = described_class.open('/test-file', 'r', &:read)
+        expect(contents).to eq('hello')
+
+        contents = described_class.open('/test-file', 'r', &:read)
+        expect(contents).to eq('hello')
+      end
+
+      context 'when only the filename is provided' do
+        context 'and the file exists' do
+          it 'returns the open file' do
+            file = described_class.new('/test-file')
+            expect(file).to be_a(MemFs::File)
+          end
+        end
+
+        context 'and the file does not exist' do
+          it 'raises an exception' do
+            expect {
+              described_class.new('missing-file')
+            }.to raise_error(Errno::ENOENT)
+          end
+        end
+
+        context 'when the file is a symlink and its target does not exist' do
+          it 'raises an exception' do
+            expect {
+              described_class.new('/no-link')
+            }.to raise_error(Errno::ENOENT)
+          end
+        end
+      end
+
       context 'when the mode is provided' do
         context 'and it is an integer' do
           subject { described_class.new('/test-file', File::RDWR) }
@@ -820,7 +848,8 @@ module MemFs
 
           it 'sets the write+create+truncate mode for "w"' do
             subject = described_class.new('/test-file', 'w')
-            expect(subject.send(:opening_mode)).to eq File::CREAT|File::TRUNC|File::WRONLY
+            expect(subject.send(:opening_mode)).to \
+              eq File::CREAT | File::TRUNC | File::WRONLY
           end
 
           it 'sets the read+write mode for "r+"' do
@@ -830,17 +859,20 @@ module MemFs
 
           it 'sets the read+write+create+truncate mode for "w+"' do
             subject = described_class.new('/test-file', 'w+')
-            expect(subject.send(:opening_mode)).to eq File::CREAT|File::TRUNC|File::RDWR
+            expect(subject.send(:opening_mode)).to \
+              eq File::CREAT | File::TRUNC | File::RDWR
           end
 
           it 'sets the write+create+append mode for "a"' do
             subject = described_class.new('/test-file', 'a')
-            expect(subject.send(:opening_mode)).to eq File::CREAT|File::APPEND|File::WRONLY
+            expect(subject.send(:opening_mode)).to \
+              eq File::CREAT | File::APPEND | File::WRONLY
           end
 
           it 'sets the read+write+create+append mode for "a+"' do
             subject = described_class.new('/test-file', 'a+')
-            expect(subject.send(:opening_mode)).to eq File::CREAT|File::APPEND|File::RDWR
+            expect(subject.send(:opening_mode)).to \
+              eq File::CREAT | File::APPEND | File::RDWR
           end
 
           it 'handles the :bom option' do
@@ -889,7 +921,9 @@ module MemFs
 
       context 'when too many arguments are given' do
         it 'raises an exception' do
-          expect { described_class.new(1, 2, 3, 4) }.to raise_error(ArgumentError)
+          expect {
+            described_class.new(1, 2, 3, 4)
+          }.to raise_error(ArgumentError)
         end
       end
     end
@@ -989,18 +1023,18 @@ module MemFs
 
       context 'when the last argument is a hash' do
         it 'passes the contained options to +open+' do
-          expect(described_class).to receive(:open)
-              .with('/test-file', File::RDONLY, encoding: 'UTF-8')
-              .and_return(subject)
+          expect(described_class).to \
+            receive(:open)
+            .with('/test-file', File::RDONLY, encoding: 'UTF-8')
+            .and_return(subject)
 
           described_class.read '/test-file', encoding: 'UTF-8'
         end
 
         context 'when it contains the +open_args+ key' do
           it 'takes precedence over the other options' do
-            expect(described_class).to receive(:open)
-                .with('/test-file', 'r')
-                .and_return(subject)
+            expect(described_class).to \
+              receive(:open).with('/test-file', 'r').and_return(subject)
 
             described_class.read '/test-file', mode: 'w', open_args: ['r']
           end
@@ -1220,7 +1254,7 @@ module MemFs
         it 'raises an exception' do
           expect {
             described_class.realdirpath '/no-dir/test-file'
-          }.to raise_error
+          }.to raise_error Errno::ENOENT
         end
       end
     end
@@ -1284,7 +1318,7 @@ module MemFs
         it 'raises an exception' do
           expect {
             described_class.realpath '/no-dir/test-file'
-          }.to raise_error
+          }.to raise_error Errno::ENOENT
         end
       end
     end
@@ -1316,6 +1350,8 @@ module MemFs
 
         context 'and the named file does not have the setgid bit set' do
           it 'returns false' do
+            _fs.chmod 0644, '/test-file'
+
             setgid = File.setgid?('/test-file')
             expect(setgid).not_to be true
           end
@@ -1343,6 +1379,8 @@ module MemFs
 
         context 'and the named file does not have the setuid bit set' do
           it 'returns false' do
+            _fs.chmod 0644, '/test-file'
+
             setuid = File.setuid?('/test-file')
             expect(setuid).not_to be true
           end
@@ -1441,10 +1479,10 @@ module MemFs
       end
 
       it 'always returns a new object' do
-        stat_1 = described_class.stat('/test-file')
-        stat_2 = described_class.stat('/test-file')
+        stat1 = described_class.stat('/test-file')
+        stat2 = described_class.stat('/test-file')
 
-        expect(stat_2).not_to be stat_1
+        expect(stat2).not_to be stat1
       end
     end
 
@@ -1458,8 +1496,9 @@ module MemFs
           expect(sticky).to be true
         end
 
-        it "returns false if the named file hasn't' the sticky bit set" do
+        it 'returns false if the named file hasn’t the sticky bit set' do
           _fs.touch '/test-file'
+          _fs.chmod 0666, '/test-file'
 
           sticky = File.sticky?('/test-file')
           expect(sticky).to be false
@@ -1540,13 +1579,17 @@ module MemFs
 
       context 'when the named file does not exist' do
         it 'raises an exception' do
-          expect { described_class.truncate '/no-file', 5 }.to raise_error
+          expect {
+            described_class.truncate '/no-file', 5
+          }.to raise_error Errno::ENOENT
         end
       end
 
       context 'when the given size is negative' do
         it 'it raises an exception' do
-          expect { described_class.truncate '/test-file', -1 }.to raise_error
+          expect {
+            described_class.truncate '/test-file', -1
+          }.to raise_error TypeError
         end
       end
     end
@@ -1803,6 +1846,54 @@ module MemFs
       end
     end
 
+    describe '.write' do
+      it 'writes the string to the given file' do
+        described_class.write('/test-file', 'test')
+        read_content = described_class.read('/test-file')
+        expect(read_content).to eq 'test'
+      end
+
+      context 'when +offset+ is provided' do
+        it 'writes the string to the given file when offset is 0' do
+          described_class.write('/test-file', 'test', 0)
+          read_content = described_class.read('/test-file')
+          expect(read_content).to eq 'test'
+        end
+
+        it 'writes the string to the given file when offset is nil' do
+          described_class.write('/test-file', 'test', nil)
+          read_content = described_class.read('/test-file')
+          expect(read_content).to eq 'test'
+        end
+
+        it 'starts writing from the offset' do
+          skip('Offsets not yet implemented in IO.write')
+          described_class.write('/test-file', 'test')
+          described_class.write('/test-file', 'test', 2)
+          read_content = described_class.read('/test-file')
+          expect(read_content).to eq 'tetest'
+        end
+
+        it 'raises an error if offset is negative' do
+          expect {
+            described_class.write('/test-file', 'foo', -1)
+          }.to raise_error Errno::EINVAL
+        end
+
+        it 'raises an error if offset is a boolean' do
+          expect {
+            described_class.write '/test-file', 'foo', false
+          }.to raise_error TypeError
+        end
+
+        it 'raises an error if offset is a string' do
+          expect {
+            described_class.write '/test-file', 'foo', 'offset'
+          }.to raise_error TypeError
+        end
+      end
+    end
+
     describe '.zero?' do
       context 'when the named file exists' do
         context 'and has a zero size' do
@@ -1906,7 +1997,7 @@ module MemFs
     end
 
     describe '#autoclose?' do
-      it "returns true by default" do
+      it 'returns true by default' do
         expect(subject.autoclose?).to be true
       end
 
@@ -1938,7 +2029,7 @@ module MemFs
         expect(subject.binmode?).to be true
       end
 
-      it "sets the file encoding to ASCII-8BIT" do
+      it 'sets the file encoding to ASCII-8BIT' do
         subject.binmode
 
         encoding = subject.external_encoding
@@ -1947,7 +2038,7 @@ module MemFs
     end
 
     describe '#binmode?' do
-      it "returns false by default" do
+      it 'returns false by default' do
         expect(subject.binmode?).to be false
       end
 
@@ -2023,7 +2114,7 @@ module MemFs
 
       it 'ignores -1 user id' do
         expect {
-          subject.chown -1, 42
+          subject.chown(-1, 42)
         }.to_not change { subject.stat.uid }
       end
 
@@ -2097,7 +2188,7 @@ module MemFs
         expect(subject.close_on_exec?).to be true
       end
 
-      context "when the close-on-exec flag is set to false" do
+      context 'when the close-on-exec flag is set to false' do
         before { subject.close_on_exec = false }
 
         it 'returns false' do
@@ -2186,7 +2277,7 @@ module MemFs
       context 'when the file is not open for reading' do
         it 'raises an exception' do
           expect {
-            write_subject.each_byte { |b| }
+            write_subject.each_byte {}
           }.to raise_error IOError
         end
 
@@ -2223,7 +2314,7 @@ module MemFs
       context 'when the file is not open for reading' do
         it 'raises an exception' do
           expect {
-            write_subject.each_char { |b| }
+            write_subject.each_char {}
           }.to raise_error IOError
         end
 
@@ -2325,19 +2416,11 @@ module MemFs
         expect(subject.lstat).to be_a File::Stat
       end
 
-      it 'does not follow the last symbolic link' do
-        file = described_class.new('/test-link')
+      context 'when the given file is a symlink' do
+        subject { described_class.new('/test-link') }
 
-        is_symlink = file.lstat.symlink?
-        expect(is_symlink).to be true
-      end
-
-      context 'when the named file is a symlink' do
-        context 'and its target does not exist' do
-          it 'ignores errors' do
-            file = described_class.new('/no-link')
-            expect { file.lstat }.not_to raise_error
-          end
+        it 'does not follow the last symbolic link' do
+          expect(subject.lstat).to be_symlink
         end
       end
     end
@@ -2507,7 +2590,7 @@ module MemFs
         expect(content).to eq "test\n"
       end
 
-      it "does not override the file's content" do
+      it 'does not override the file’s content' do
         write_subject.puts 'test'
         write_subject.puts 'test'
         write_subject.close
@@ -2599,7 +2682,7 @@ module MemFs
 
       context 'when +whence+ is IO::SEEK_END' do
         it 'seeks to +amount+ plus end of stream' do
-          subject.seek -1, ::IO::SEEK_END
+          subject.seek(-1, ::IO::SEEK_END)
 
           expect(subject.pos).to be 4
         end
@@ -2621,7 +2704,7 @@ module MemFs
 
       context 'if the position ends up to be less than zero' do
         it 'raises an exception' do
-          expect { subject.seek -1 }.to raise_error Errno::EINVAL
+          expect { subject.seek(-1) }.to raise_error Errno::EINVAL
         end
       end
     end
